import java.util.ArrayList;

/**
 * A class to hold details of audio files.
 * 
 * @author David J. Barnes and Michael Klling
 * @version 2011.07.31
 */
public class MusicCollection
{
    // An ArrayList for storing the file names of music files.
    private ArrayList<Music> files;
    // A player for the music files.
    private MusicPlayer player;
        
    /**
     * Create a MusicCollection
     */
    public MusicCollection()
    {
        files = new ArrayList<Music>() ;
        player = new MusicPlayer() ;
    }
    
    /**
     * Add a file to the collection.
     * @param filename The file to be added.
     */
    public void addFile(Music music)
    {
        files.add(music) ;
    }
    
    /**
     * Return the number of files in the collection.
     * @return The number of files in the collection.
     */
    public int getNumberOfFiles()
    {
        return files.size() ;
    }
    
    /**
     * List a file from the collection.
     * @param index The index of the file to be listed.
     */
    public void listFile(int index)
    {
    	if(validIndex(index)) {
    		System.out.println("MusicName is"
        			+ files.get(index).getMusicName() 
        			+ "singerName is :  "
        			+ files.get(index).getMusicSinger()
        			+ "yearOfProduce is :  "
        			+ files.get(index).getMusicYear() ); 
    	}
    	else
    		System.out.println("Index is not valid!");
        
    }
    
    /**
     * Show a list of all the files in the collection.
     */
    public void listAllFiles(String kindOfSong)
    {
    	System.out.println("In a "+kindOfSong+" collection these are our songs\n");
        for(Music it : files) {
        	System.out.println("MusicName is:  "
        			+ it.getMusicName() 
        			+ "  singerName is :  "
        			+ it.getMusicSinger()
        			+ "  yearOfProduce is :  "
        			+ it.getMusicYear()+ "" ); 
        }
        System.out.println() ;
    }
    
    /**
     * Remove a file from the collection.
     * @param index The index of the file to be removed.
     */
    public void removeFile(int index)
    {
    	if(validIndex(index))
    		files.remove(index) ;
    	else
    		System.out.println("Index is not valid!");
    }

    /**
     * Start playing a file in the collection.
     * Use stopPlaying() to stop it playing.
     * @param index The index of the file to be played.
     */
    public void startPlaying(int index)
    {
    	if(validIndex(index)) {
	    	String fileName = files.get(index).getMusicName() ;
	        player.startPlaying(fileName);
    	}
    	else
    		System.out.println("Index is not valid!");
    }

    /**
     * Stop the player.
     */
    public void stopPlaying()
    {
        player.stop();
    }


    /**
     * Determine whether the given index is valid for the collection.
     * Print an error message if it is not.
     * @param index The index to be checked.
     * @return true if the index is valid, false otherwise.
     */
    private boolean validIndex(int index)
    {
    	// The return value.
        // Set according to whether the index is valid or not.
    	if(index < 0 )
    		return false ;
    	else if( index < getNumberOfFiles())
    		return true ;
    	else
    		return false ;
    }
    /**
     * Search the music with entering Name or NameOfSinger of music
     * @param str Name or Name of singer that we enter
     * 
     */
    public void searchMusic(String str) {
    	// to determine searchResult is true or false
    	boolean searchResult = false ;
    	System.out.println("Result of search :");
    	for(Music it : files) {
    		if(it.getMusicName().equals(str) || it.getMusicSinger().equals(str) ) {
    			System.out.println("The music was found! :-)");
        		System.out.println("MusicNameIs:  "
        		+ it.getMusicName() 
        		+ "  SingerNameIs:  " 
        		+ it.getMusicSinger() 
        		+ "  YearOfProduce:  " 
        		+ it.getMusicYear());
    			searchResult = true ;
    			break ;
    		}
    	}
    	if(searchResult == false)
    		System.out.println("The Music Not found!");
    }
}